@@ -13,64 +13,64 @@ require AutoLoader;
 @EXPORT = qw();
 @EXPORT_OK = qw(rur_in_words);
 
-$VERSION = '0.05';
+$VERSION = '0.6';
 
 # Preloaded methods go here.
 use vars qw(%diw %nom);
 
 %diw = (
     0 => {
-        0  => { 0 => "",         1 => 1},
+        0  => { 0 => "ноль",         1 => 1},
         1  => { 0 => "",             1 => 2},
         2  => { 0 => "",             1 => 3},
-        3  => { 0 => "",          1 => 0},
-        4  => { 0 => "",       1 => 0},
-        5  => { 0 => "",         1 => 1},
-        6  => { 0 => "",        1 => 1},
-        7  => { 0 => "",         1 => 1},
-        8  => { 0 => "",       1 => 1},
-        9  => { 0 => "",       1 => 1},
-        10 => { 0 => "",       1 => 1},
-        11 => { 0 => "",   1 => 1},
-        12 => { 0 => "",   1 => 1},
-        13 => { 0 => "",   1 => 1},
-        14 => { 0 => "", 1 => 1},
-        15 => { 0 => "",   1 => 1},
-        16 => { 0 => "",  1 => 1},
-        17 => { 0 => "",   1 => 1},
-        18 => { 0 => "", 1 => 1},
-        19 => { 0 => "", 1 => 1},
+        3  => { 0 => "три",          1 => 0},
+        4  => { 0 => "четыре",       1 => 0},
+        5  => { 0 => "пять",         1 => 1},
+        6  => { 0 => "шесть",        1 => 1},
+        7  => { 0 => "семь",         1 => 1},
+        8  => { 0 => "восемь",       1 => 1},
+        9  => { 0 => "девять",       1 => 1},
+        10 => { 0 => "десять",       1 => 1},
+        11 => { 0 => "одиннадцать",   1 => 1},
+        12 => { 0 => "двенадцать",   1 => 1},
+        13 => { 0 => "тринадцать",   1 => 1},
+        14 => { 0 => "четырнадцать", 1 => 1},
+        15 => { 0 => "пятнадцать",   1 => 1},
+        16 => { 0 => "шестнадцать",  1 => 1},
+        17 => { 0 => "семнадцать",   1 => 1},
+        18 => { 0 => "восемнадцать", 1 => 1},
+        19 => { 0 => "девятнадцать", 1 => 1},
     },
     1 => {
-        2  => { 0 => "",    1 => 1},
-        3  => { 0 => "",    1 => 1},
-        4  => { 0 => "",       1 => 1},
-        5  => { 0 => "",   1 => 1},
-        6  => { 0 => "",  1 => 1},
-        7  => { 0 => "",   1 => 1},
-        8  => { 0 => "", 1 => 1},
-        9  => { 0 => "",   1 => 1},
+        2  => { 0 => "двадцать",    1 => 1},
+        3  => { 0 => "тридцать",    1 => 1},
+        4  => { 0 => "сорок",       1 => 1},
+        5  => { 0 => "пятьдесят",   1 => 1},
+        6  => { 0 => "шестьдесят",  1 => 1},
+        7  => { 0 => "семьдесят",   1 => 1},
+        8  => { 0 => "восемьдесят", 1 => 1},
+        9  => { 0 => "девяносто",   1 => 1},
     },
     2 => {
-        1  => { 0 => "",       1 => 1},
-        2  => { 0 => "",    1 => 1},
-        3  => { 0 => "",    1 => 1},
-        4  => { 0 => "", 1 => 1},
-        5  => { 0 => "",   1 => 1},
-        6  => { 0 => "",  1 => 1},
-        7  => { 0 => "",   1 => 1},
-        8  => { 0 => "", 1 => 1},
-        9  => { 0 => "", 1 => 1}
+        1  => { 0 => "сто",       1 => 1},
+        2  => { 0 => "двести",    1 => 1},
+        3  => { 0 => "триста",    1 => 1},
+        4  => { 0 => "четыреста", 1 => 1},
+        5  => { 0 => "пятьсот",   1 => 1},
+        6  => { 0 => "шестьсот",  1 => 1},
+        7  => { 0 => "семьсот",   1 => 1},
+        8  => { 0 => "восемьсот", 1 => 1},
+        9  => { 0 => "девятьсот", 1 => 1}
     }
 );
 
 %nom = (
-    0  =>  {0 => "",  1 => "",    2 => " ", 3 => " "},
-    1  =>  {0 => "",    1 => "",    2 => " ",   3 => " "},
-    2  =>  {0 => "",   1 => "",     2 => " ",  3 => " "},
-    3  =>  {0 => "", 1 => "", 2 => " ", 3 => " "},
-    4  =>  {0 => "",1 => "",2 => " ",3 => " "},
-    5  =>  {0 => "",1 => "",2 => " ",3 => " "}
+    0  =>  {0 => "копейки",  1 => "копеек",    2 => "одна копейка", 3 => "две копейки"},
+    1  =>  {0 => "рубля",    1 => "рублей",    2 => "один рубль",   3 => "два рубля"},
+    2  =>  {0 => "тысячи",   1 => "тысяч",     2 => "одна тысяча",  3 => "две тысячи"},
+    3  =>  {0 => "миллиона", 1 => "миллионов", 2 => "один миллион", 3 => "два миллиона"},
+    4  =>  {0 => "миллиарда",1 => "миллиардов",2 => "один миллиард",3 => "два миллиарда"},
+    5  =>  {0 => "триллиона",1 => "триллионов",2 => "один триллион",3 => "два триллиона"}
 );
 
 my $out_rub;
@@ -96,7 +96,7 @@ sub rur_in_words
         $sum_rub-- if ($sum_rub - $sum_tmp > 0);
         $retval = get_string($sum_part, $i)." ".$retval;
     }
-    $retval .= " " if ($out_rub == 0);
+    $retval .= " рублей" if ($out_rub == 0);
     $retval .= " ".$kop;
     $retval =~ s/\s+/ /g;
     return $retval;
@@ -164,7 +164,7 @@ Lingua::RU::Number - Converts numbers to money sum in words (in Russian roubles)
 B<Lingua::RU::Number::rur_in_words()> helps you convert number to money sum in words.
 Given a number, B<rur_in_words()> returns it as money sum in words, e.g.: 1.01 converted
 to I<odin rubl' odna kopejka>, 2.22 converted to I<dwa rublja dwadcat' dwe kopejki>.
-The target cyrillic charset is B<windows-1251>.
+The target charset is B<UTF-8>.
 
 =head1 BUGS
 
@@ -176,7 +176,7 @@ Vladislav Safronov, E<lt>F<vlad at yandex.ru>E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002 by Vladislav Safronov.
+Copyright (C) 2002-2015 by Vladislav Safronov.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
